@@ -1,3 +1,25 @@
+/****************************************************************************
+* VCGLib                                                            o o     *
+* Visual and Computer Graphics Library                            o     o   *
+*                                                                _   O  _   *
+* Copyright(C) 2004-2016                                           \/)\/    *
+* Visual Computing Lab                                            /\/|      *
+* ISTI - Italian National Research Council                           |      *
+*                                                                    \      *
+* All rights reserved.                                                      *
+*                                                                           *
+* This program is free software; you can redistribute it and/or modify      *   
+* it under the terms of the GNU General Public License as published by      *
+* the Free Software Foundation; either version 2 of the License, or         *
+* (at your option) any later version.                                       *
+*                                                                           *
+* This program is distributed in the hope that it will be useful,           *
+* but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+* GNU General Public License (http://www.gnu.org/licenses/gpl.txt)          *
+* for more details.                                                         *
+*                                                                           *
+****************************************************************************/
 #ifndef NORMAL_EXTRAPOLATION_H
 #define NORMAL_EXTRAPOLATION_H
 
@@ -121,10 +143,19 @@ public:
     if(p.coherentAdjNum==0) return;
 //    tree.setMaxNofNeighbors(p.coherentAdjNum+1);
 
+    if(p.useViewPoint) // Simple case use the viewpoint position to determine the right orientation of each point
+    {
+      for(VertexIterator vi=m.vert.begin();vi!=m.vert.end();++vi)
+      {
+        if ( vi->N().dot(p.viewPoint- vi->P())<0.0f)
+            vi->N()=-(*vi).N();
+      }
+      return;
+    }
+
     tri::UpdateFlags<MeshType>::VertexClearV(m);
     std::vector<WArc> heap;
     VertexIterator vi=m.vert.begin();
-
     while(true)
     {
       // search an unvisited vertex
@@ -133,10 +164,6 @@ public:
 
       if(vi==m.vert.end()) return;
 
-      if ( p.useViewPoint &&
-          ( vi->N().dot(p.viewPoint- vi->P())<0.0f) )
-          vi->N()=-(*vi).N();
-
       vi->SetV();
       AddNeighboursToHeap(m,&*vi,p.coherentAdjNum,tree,heap);
 
@@ -149,7 +176,6 @@ public:
         {
           a.trg->SetV();
           if(a.src->cN()*a.trg->cN()<0.0f)
-            if(!p.useViewPoint || ( a.trg->N().dot(p.viewPoint- a.trg->P())<0.0f)) // test to prevent flipping according to viewpos
               a.trg->N()=-a.trg->N();
           AddNeighboursToHeap(m,a.trg,p.coherentAdjNum,tree,heap);
         }
